aboutsummaryrefslogtreecommitdiff
path: root/jb/api/magic_token.py
diff options
context:
space:
mode:
authorMax Nanis2026-09-11 11:27:58 -0700
committerMax Nanis2026-09-11 11:27:58 -0700
commitedff9381275d90d7be5f078430554ae592a27f5d (patch)
treea2efa8e83a11c810349ad1a7c50e44f55a127fa4 /jb/api/magic_token.py
parentcb5e40f9b5fb0ae4bb9a769dd7a9c83c2af18a65 (diff)
downloadamt-jb-edff9381275d90d7be5f078430554ae592a27f5d.tar.gz
amt-jb-edff9381275d90d7be5f078430554ae592a27f5d.zip
Current jb flask testing state.
Diffstat (limited to 'jb/api/magic_token.py')
-rw-r--r--jb/api/magic_token.py2
1 files changed, 1 insertions, 1 deletions
diff --git a/jb/api/magic_token.py b/jb/api/magic_token.py
index 910dc12..b60d5e9 100644
--- a/jb/api/magic_token.py
+++ b/jb/api/magic_token.py
@@ -9,7 +9,7 @@ from jb.models.auth import AmtAccountLink
MAGIC_TOKEN_PREFIX = "auth:magic:"
AMT_ACCOUNT_LINK_TOKEN_PREFIX = "auth:amt-account-link:"
-MAGIC_TOKEN_TTL: int = 5 * 60 # 5 minutes, in seconds
+MAGIC_TOKEN_TTL: int = 10 * 60 # 10 minutes, in seconds
def redis_token_key(token: str, prefix: str = MAGIC_TOKEN_PREFIX) -> str: